mailr9665 - /branches/bmrb/bmrblib/kinetics/relaxation.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on October 08, 2009 - 17:51:
Author: bugman
Date: Thu Oct  8 17:51:22 2009
New Revision: 9665

URL: http://svn.gna.org/viewcvs/relax?rev=9665&view=rev
Log:
Fixes for the Relaxation_v3_1 saveframe class.  This should set up all the 
v3.1 relaxation classes.


Modified:
    branches/bmrb/bmrblib/kinetics/relaxation.py

Modified: branches/bmrb/bmrblib/kinetics/relaxation.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/bmrb/bmrblib/kinetics/relaxation.py?rev=9665&r1=9664&r2=9665&view=diff
==============================================================================
--- branches/bmrb/bmrblib/kinetics/relaxation.py (original)
+++ branches/bmrb/bmrblib/kinetics/relaxation.py Thu Oct  8 17:51:22 2009
@@ -74,10 +74,23 @@
 
 
 class Relaxation_v3_1(Relaxation_v3_0):
-    """Class for the relaxation data part of the BMRB API (v3.1).
-    
-    Currently this is the same as for v3.0.
-    """
+    """Class for the relaxation data part of the BMRB API (v3.1)."""
+
+    def __init__(self, datanodes):
+        """Initialise the class, placing the pystarlib data nodes into the 
namespace.
+
+        @param datanodes:   The pystarlib data nodes object.
+        @type datanodes:    list
+        """
+
+        # Place the data nodes into the namespace.
+        self.__datanodes = datanodes
+
+        # Initialise the kinetic saveframe supergroups.
+        self.__heteronucl_NOEs = 
HeteronuclNOESaveframe_v3_1(self.__datanodes)
+        self.__heteronucl_T1_relaxation = 
HeteronuclT1Saveframe_v3_1(self.__datanodes)
+        self.__heteronucl_T2_relaxation = 
HeteronuclT2Saveframe_v3_1(self.__datanodes)
+
 
 
 class Relaxation_v3_2(Relaxation_v3_1):




Related Messages


Powered by MHonArc, Updated Thu Oct 08 18:20:02 2009